1 |
A data frame with 20 observations on the following 100 variables.
lab_opieida factor with levels 09ISW034654/01 09LIV003872/01 09LIV006355/01 09LIV009557/01 09LIV016856/01 09LIV020231/01 09SLY017471/01 09ZWT025960/01 09ZXC023311/01 09ZXK039504/01 09ZXK039700/01 09ZXK040794/01 10BOL007094/01 10FRE057722/01 10LIV045064/01 10MMM021350/01 10NOT137976/01 10ZWG152209/01 10ZWG165532/01
hes_IDa numeric vector
hes_hesid_count_duplicatesa numeric vector
lab_organismnamea factor with levels COLIFORM ENTEROBACTER CLOACAE ENTEROCOCCUS FAECALIS ENTEROCOCCUS SP KLEBSIELLA PNEUMONIAE MORAXELLA CATARRHALIS PANTOEA SP PSEUDOMONAS AERUGINOSA STAPHYLOCOCCUS COAGULASE NEGATIVE
lab_groupa factor with levels COAGULASE NEGATIVE STAPHYLOCOCCUS ENTEROBACTER ENTEROCOCCUS KLEBSIELLA other P. AERUGINOSA
lab_GRAMEXTa factor with levels N P
Xa numeric vector
lab_Specimendatea factor with levels 2009-01-09 2009-06-04 2009-08-11 2009-08-25 2009-08-28 2009-09-01 2009-09-15 2009-09-27 2009-10-23 2009-10-29 2009-11-11 2009-11-27 2009-12-08 2010-01-07 2010-01-30 2010-02-08 2010-02-25 2010-03-04
hes_admdtea factor with levels 2008-10-02 2009-05-24 2009-07-20 2009-08-18 2009-08-22 2009-09-07 2009-09-23 2009-10-12 2009-11-01 2009-12-05 2010-01-04 2010-01-05 2010-01-21 2010-03-02
hes_disdtea factor with levels 2009-03-11 2009-06-16 2009-09-21 2009-09-23 2009-10-13 2009-11-10 2009-11-21 2010-01-10 2010-01-18 2010-01-30 2010-02-16 2010-03-11 2010-03-17
adm_diff_specdatea numeric vector
dis_diff_specdatea numeric vector
adm_diff_disa numeric vector
lab_AMPAMOXa numeric vector
lab_CTXa numeric vector
lab_CTZa numeric vector
lab_CTRIa numeric vector
lab_GENTa numeric vector
lab_IMIa numeric vector
lab_MEROa numeric vector
lab_METa numeric vector
lab_PIPTAZa numeric vector
lab_labnamea factor with levels CHELSEA AND WESTMINSTER HOSPITAL (LONDON) HILLINGDON HOSPITAL (MIDDLESEX) HPA NORTH WEST MANCHESTER LABORATORY IPSWICH MICROBIOLOGY LABORATORY NOTTINGHAM MICROBIOLOGY LABORATORY SALISBURY MICROBIOLOGY LABORATORY SOUTHMEAD HOSPITAL (BRISTOL) ST HELIER HOSPITAL (CARSHALTON) ST MARY'S HOSPITAL (LONDON)} \code{UNIVERSITY COLLEGE HOSPITAL (LONDON)}}
\item{\code{lab_currentregionname}}{a factor with levels \code{E MIDS} \code{EAST} \code{LONDON} \code{N WEST} \code{S WEST}}
\item{\code{lab_CoNSmet}}{a numeric vector}
\item{\code{lab_AMINOAMOX1}}{a numeric vector}
\item{\code{lab_AMINOMET1}}{a numeric vector}
\item{\code{lab_AMINOVAN1}}{a numeric vector}
\item{\code{lab_CTXI1}}{a numeric vector}
\item{\code{lab_pen}}{a numeric vector}
\item{\code{lab_met}}{a numeric vector}
\item{\code{lab_van2}}{a numeric vector}
\item{\code{lab_AMINOAMOXAMP1}}{a numeric vector}
\item{\code{lab_AMINOPIPTAZ1}}{a numeric vector}
\item{\code{lab_AMINOCTZ1}}{a numeric vector}
\item{\code{lab_AMINOIMI1}}{a numeric vector}
\item{\code{lab_AMINOMER1}}{a numeric vector}
\item{\code{lab_CTXI2}}{a numeric vector}
\item{\code{hes_sexdescription}}{a factor with levels \code{Female} \code{Male}}
\item{\code{hes_ageatstartofepisode}}{a numeric vector}
\item{\code{hes_neocaredescription}}{a factor with levels \code{Not applicable} \code{Not known} \code{Special care}}
\item{\code{hes_admimethdescription}}{a factor with levels \code{Elective - booked} \code{Elective - planned} \code{Emergency - other means, including patients who arrive via A&E department of another HC provider} \code{Maternity - where baby was delivered after mother's admission Other - babies born in HC provider Transfer of any admitted patient from another hospital provider
hes_admisorcdescriptiona factor with levels Babies born in or on the way to hospital NHS other hospital provider - ward for general patients or the younger phys. disabled or A&E depatment (from 1 April 2004) NHS other hospital provider - ward for maternity patients or neonatal ward (from 1 April 2004) The usual place of residence, including no fixed abode
hes_dismethdescriptiona factor with levels Died Discharged on clinical advice or with clinical consent
hes_dischargeddeadoralivea factor with levels Death Live
X.1a numeric vector
hes_disdestdescriptiona factor with levels Death, including still birth NHS other hospital provider - ward for general patients or the younger phys. disabled (from 1 April 2004) NHS other hospital provider - ward for maternity patients or neonates (from 1 April 2004) NHS run care home (from 1 April 2004) The usual place of residence, including no fixed abode
hes_diag1descriptiona factor with levels Acute lymphoblastic leukaemia Acute myeloid leukaemia Adenoviral pneumonia Congenital absence, atresia and stenosis of ileum Crohn's disease of small intestine} \code{Extremely low birth weight} \code{Labour and delivery complicated by fetal heart rate anomaly} \code{Malignant neoplasm, other sarcomas of liver} \code{Other and unspecified intestinal obstruction} \code{Other low birth weight} \code{Other specified congenital malformations of skin} \code{Postoperative intestinal obstruction}}
\item{\code{hes_diag1_code_primary}}{a factor with levels \code{C224-} \code{C910-} \code{C920} \code{J120-} \code{K500-} \code{K566} \code{K913-} \code{O680} \code{P070} \code{P071} \code{Q412} \code{Q828}}
\item{\code{hes_diag2description}}{a factor with levels \code{} \code{Abnormal weight loss} \code{Agranulocytosis} \code{Anaemia, unspecified} \code{Colostomy and enterostomy malfunction} \code{Down's syndrome, unspecified Hepatic fibrosis Hyperkinetic disorder, unspecified Intestinal adhesions [bands] with obstruction Necrotizing enterocolitis of fetus and newborn Pleural effusion, not elsewhere classified Respiratory syncytial virus pneumonia Single live birth Staph aureus as cause of dis classified to other chapters Twin, born in hospital
hes_diag2_codea factor with levels B956 D649- D70X- F909- J121- J90X K565- K740 K914- P77X Q909- R634 Z370 Z383
hes_diag3descriptiona factor with levels Acute bronchiolitis due to respiratory syncytial virus Agranulocytosis Anaemia, unspecified Bronchopulmonary dysplasia origin in the perinatal period Childhood autism Essential (primary) hypertension Flatulence and related conditions Glossodynia Hyperkinetic disorder, unspecified Infection following a procedure, not elsewhere classified Necrotizing enterocolitis of fetus and newborn Other generalized epilepsy and epileptic syndromes Pyrexia of unknown origin following delivery Sepsis of newborn due to Escherichia coli
hes_diag3_codea factor with levels D649 D70X- F840- F909- G404- I10X J210 K146- O864 P271 P364 P77X- R14X T814-
hes_diag4descriptiona factor with levels Childhood autism Developmental disorder of scholastic skills, unspecified Down's syndrome, unspecified} \code{Fever, unspecified} \code{Fluid overload} \code{Haemorrhage into co-twin} \code{Other bacterial meningitis} \code{Other preterm infants} \code{Other spec bact agents as cause of dis class oth chaps} \code{Other spec dis and conditions comp preg childbirth puerp} \code{Other specified septicaemia} \code{Primary pulmonary hypertension} \code{Pulmonary collapse} \code{Thrombocytopenia, unspecified}}
\item{\code{hes_diag4_code}}{a factor with levels \code{} \code{A418} \code{B968-} \code{D696} \code{E877-} \code{F819} \code{F840-} \code{G008} \code{I270-} \code{J981-} \code{O998} \code{P073-} \code{P503} \code{Q909-} \code{R509}}
\item{\code{hes_diag5description}}{a factor with levels \code{} \code{Chest pain, unspecified} \code{Decubitus ulcer} \code{Dyspnoea} \code{Escherichia coli as cause of dis classified to other chaps} \code{Fet and newborn affected by placental transfusion syndr} \code{Fever, unspecified} \code{Gastro-oesophageal reflux disease without oesophagitis} \code{Hypotension, unspecified} \code{Noninfective gastroenteritis and colitis, unspecified} \code{Ocular pain} \code{Personal hist of cong malf'ns deform'ns/chromosomal abnms} \code{Thrombocytopenia, unspecified}}
\item{\code{hes_diag5_code}}{a factor with levels \code{} \code{B962} \code{D696} \code{H571-} \code{I959-} \code{K219-} \code{K529-} \code{L89X} \code{P023} \code{R060} \code{R074-} \code{R509-} \code{Z877}}
\item{\code{hes_diag6description}}{a factor with levels \code{} \code{Acquired absence of other parts of digestive tract} \code{Agranulocytosis} \code{Chemotherapy session for neoplasm} \code{Haematemesis} \code{Hypo-osmolality and hyponatraemia} \code{Low back pain} \code{Neonatal jaundice associated with preterm delivery} \code{Other disorders of bilirubin metabolism} \code{Other feeding problems of newborn} \code{Other lack of expected normal physiological development}}
\item{\code{hes_diag6_code}}{a factor with levels \code{} \code{D70X} \code{E806} \code{E871-} \code{K920-} \code{M5458} \code{P590} \code{P928} \code{R628-} \code{Z511-} \code{Z904-}}
\item{\code{hes_diag7description}}{a factor with levels \code{} \code{Epistaxis} \code{Melaena} \code{Other antineopastic drugs} \code{Other lack of expected normal physiological development} \code{Other viral infections of unspecified site} \code{Personal history of allergy to analgesic agent} \code{Personal history of diseases of the digestive system}}
\item{\code{hes_diag7_code}}{a factor with levels \code{} \code{B348-} \code{K921-} \code{R040} \code{R628-} \code{Y433} \code{Z871-} \code{Z886-}}
\item{\code{hes_diag8description}}{a factor with levels \code{} \code{Anaemia, unspecified} \code{Cough} \code{Infect inflamm reac due oth card vasc devs implant and graft} \code{Infection following a procedure, not elsewhere classified} \code{Personal history of dis of the nervous sys and sense organs}}
\item{\code{hes_diag8_code}}{a factor with levels \code{} \code{D649} \code{R05X-} \code{T814-} \code{T827} \code{Z866-}}
\item{\code{hes_diag9description}}{a factor with levels \code{} \code{Hepatomegaly with splenomegaly, not elsewhere classified} \code{Klebsiella pneumoniae as cause dis class other chaps} \code{Oedema, unspecified} \code{Other and unspecified abdominal pain}}
\item{\code{hes_diag9_code}}{a factor with levels \code{} \code{B961-} \code{R104-} \code{R162} \code{R609}}
\item{\code{hes_diag10description}}{a factor with levels \code{} \code{Acute nasopharyngitis [common cold]} \code{Megacolon, not elsewhere classified} \code{Nausea and vomiting} \code{Septicaemia due to other Gram-negative organisms}}
\item{\code{hes_diag10_code}}{a factor with levels \code{} \code{A415-} \code{J00X} \code{K593} \code{R11X-}}
\item{\code{hes_diag11description}}{a factor with levels \code{} \code{Fever, unspecified} \code{Hypokalaemia}}
\item{\code{hes_diag11_code}}{a factor with levels \code{} \code{E876} \code{R509-}}
\item{\code{hes_diag12description}}{a factor with levels \code{} \code{Pericardial effusion (noninflammatory)} \code{Tachycardia, unspecified}}
\item{\code{hes_diag12_code}}{a factor with levels \code{} \code{I313-} \code{R000}}
\item{\code{hes_diag13description}}{a factor with levels \code{} \code{Anxiety disorder, unspecified} \code{Carrier of other specified bacterial diseases}}
\item{\code{hes_diag13_code}}{a factor with levels \code{} \code{F419} \code{Z223-}}
\item{\code{hes_diag14description}}{a logical vector}
\item{\code{hes_diag14_code}}{a logical vector}
\item{\code{hes_diag15description}}{a logical vector}
\item{\code{hes_diag15_code}}{a logical vector}
\item{\code{hes_diag16description}}{a logical vector}
\item{\code{hes_diag16_code}}{a logical vector}
\item{\code{hes_diag17description}}{a logical vector}
\item{\code{hes_diag17_code}}{a logical vector}
\item{\code{hes_diag18description}}{a logical vector}
\item{\code{hes_diag18_code}}{a logical vector}
\item{\code{hes_diag19description}}{a logical vector}
\item{\code{hes_diag19_code}}{a logical vector}
\item{\code{hes_diag20description}}{a logical vector}
\item{\code{hes_diag20_code}}{a logical vector}
\item{\code{hes_oper1description}}{a factor with levels \code{-} \code{All normal delivery} \code{Delivery of subsequent element of cycle of chemotherapy for neoplasm} \code{Ileectomy and anastomosis of ileum to ileum} \code{Injection of therapeutic substance into cerebrospinal fluid} \code{Intravenous nutrition Band 1} \code{Non-invasive ventilation NEC} \code{Resection of ileo-colic anastomosis} \code{Unspecified diagnostic spinal puncture}}
\item{\code{hes_op1_maincode}}{a factor with levels \code{-} \code{A542} \code{A559} \code{E852} \code{G693} \code{G734} \code{R249} \code{X724} \code{X904}}
\item{\code{hes_oper2description}}{a factor with levels \code{} \code{Diagnostic extraction of bone marrow NEC} \code{Episiotomy to facilitate delivery} \code{Freeing of adhesions of peritoneum} \code{Intravenous immunotherapy} \code{Intravenous nutrition Band 1} \code{Lumbar spinal cord} \code{Other specified procurement of drugs for chemotherapy for neoplasm in Bands 1-5}}
\item{\code{hes_op2_code}}{a factor with levels \code{} \code{R271} \code{T413} \code{W365} \code{X353} \code{X708} \code{X904} \code{Z063}}
\item{\code{hes_oper3description}}{a factor with levels \code{} \code{Intravenous nutrition Band 1} \code{Other specified procurement of drugs for chemotherapy for neoplasm in Bands 1-5} \code{Transthoracic echocardiography} \code{Unspecified creation of artificial opening into ileum} \code{Unspecified phototherapy to skin} \code{Wing of ilium}}
\item{\code{hes_op3_code}}{a factor with levels \code{} \code{G749} \code{S129} \code{U201} \code{X708} \code{X904} \code{Z753}}
\item{\code{hes_oper4description}}{a factor with levels \code{} \code{Cytokine inhibitor drugs Band 1} \code{Intravenous blood transfusion of packed cells} \code{Neutropenia drugs Band 1} \code{Open insertion of central venous catheter} \code{Right sided operation}}
\item{\code{hes_op4_code}}{a factor with levels \code{} \code{L911} \code{X332} \code{X903} \code{X921} \code{Z942}}
\item{\code{hes_oper5description}}{a factor with levels \code{} \code{Antifungal drugs Band 2} \code{Attention to central venous catheter NEC} \code{Procurement of drugs for chemotherapy for neoplasm for regimens in Band 1} \code{Specified vein NEC}}
\item{\code{hes_op5_code}}{a factor with levels \code{} \code{L913} \code{X701} \code{X862} \code{Z398}}
\item{\code{hes_procode5description}}{a factor with levels \code{CENTRAL MANCHESTER UNIVERSITY HOSPITALS NHS FOUNDATION TRUST} \code{CHELSEA AND WESTMINSTER HOSPITAL NHS FOUNDATION TRUST} \code{EPSOM AND ST HELIER UNIVERSITY HOSPITALS NHS TRUST} \code{IMPERIAL COLLEGE HEALTHCARE NHS TRUST} \code{IPSWICH HOSPITAL NHS TRUST} \code{NORTH BRISTOL NHS TRUST} \code{NOTTINGHAM UNIVERSITY HOSPITALS NHS TRUST - QUEEN'S MEDICAL CENTRE CAMPUS SALISBURY HEALTH CARE NHS TRUST THE HILLINGDON HOSPITAL NHS TRUST UNIVERSITY COLLEGE HOSPITAL
hes_digitprovidercodea factor with levels RAS00 RGQ00 RNZ00 RQM00 RRV03 RVJ00 RVR00 RW300 RX1RA RYJ
hes_admincat_descriptiona factor with levels NHS patient
1 2 | data(infdata_sample)
## maybe str(infdata_sample) ; plot(infdata_sample) ...
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.