1 |
A data frame with 20 observations on the following 64 variables.
IDa numeric vector
sexdescriptiona factor with levels Female Male
ageatstartofepisodea numeric vector
neocaredescriptiona factor with levels Level 1 intensive care Level 2 intensive care Normal care Not applicable Not known Special care
admimethdescriptiona factor with levels Elective - from waiting list Emergency - other means, including patients who arrive via A&E department of another HC provider Emergency - via A&E services, including casualty department of provider Emergency - via General Practitioner (GP) Other - babies born in HC provider Transfer of any admitted patient from another hospital provider
admisorcdescriptiona factor with levels Babies born in or on the way to hospital NHS other hospital provider - ward for general patients or the younger phys. disabled or A&E depatment (from 1 April 2004) The usual place of residence, including no fixed abode
dismethdescriptiona factor with levels Discharged on clinical advice or with clinical consent Not applicable patient still in hospital
dischargeddeadoralivea factor with levels Live
disdestdescriptiona factor with levels NHS other hospital provider - ward for general patients or the younger phys. disabled (from 1 April 2004) NHS other hospital provider - ward for maternity patients or neonates (from 1 April 2004) Not applicable The usual place of residence, including no fixed abode
admissiondatea factor with levels 03/07/2008 05/07/2008 07/08/2008 08/03/2009 11/01/2009 11/03/2009 11/07/2008 12/07/2008 13/02/2009 13/08/2008 14/08/2008 17/07/2008 21/03/2009 24/07/2008 26/07/2008 27/07/2008 30/03/2009
dischargedatea factor with levels 05/07/2008 08/08/2008 10/03/2009 11/03/2009 12/01/2009 12/07/2008 13/02/2009 13/08/2008 16/08/2008 17/07/2008 21/03/2009 21/07/2008 24/07/2008 26/07/2008 27/07/2008 30/03/2009 30/07/2008
diag1descriptiona factor with levels Acute upper respiratory infection, unspecified Bacterial sepsis of newborn, unspecified Fever, unspecified Gastro-oesophageal reflux disease without oesophagitis Health supervision and care other healthy infant and child Hirschsprung's disease} \code{Neonatal erythema toxicum} \code{Neonatal skin infection} \code{Other congenital malformations of eyelid} \code{Other spec conditions originating in the perinatal period} \code{Other specified congenital malformations of intestine} \code{Viral intestinal infection, unspecified} \code{Wheezing}}
\item{\code{primarydiagnosis}}{a factor with levels \code{A084} \code{J069} \code{J069-} \code{K219} \code{K219-} \code{P369-} \code{P394-} \code{P831-} \code{P968} \code{P968-} \code{Q103} \code{Q431} \code{Q438} \code{R062-} \code{R509-} \code{Z762-}}
\item{\code{diag2description}}{a factor with levels \code{} \code{Congenital adrenogenital disorders associated enzyme def} \code{Neonatal cardiac dysrhythmia} \code{Neonatal jaundice, unspecified} \code{Other atopic dermatitis} \code{Rash and other nonspecific skin eruption} \code{Unspec staphy as cause of dis classif to other chapters} \code{Vomiting in newborn}}
\item{\code{stsecondarysubsidiarydiagnosis}}{a factor with levels \code{} \code{B958-} \code{E250-} \code{L208} \code{P291} \code{P599-} \code{P920} \code{R21X}}
\item{\code{diag3description}}{a factor with levels \code{} \code{Other neonatal hypoglycaemia} \code{Procedure not carried out for other reasons} \code{Respiratory distress syndrome of newborn}}
\item{\code{ndsecondarydiagnosis}}{a factor with levels \code{} \code{P220-} \code{P704-} \code{Z538}}
\item{\code{diag4description}}{a factor with levels \code{} \code{Abnormal weight loss} \code{Other specified respiratory conditions of newborn}}
\item{\code{rdsecondarydiagnosis}}{a factor with levels \code{} \code{P288-} \code{R634-}}
\item{\code{diag5description}}{a factor with levels \code{} \code{Neonatal cardiac dysrhythmia}}
\item{\code{thsecondarydiagnosis}}{a factor with levels \code{} \code{P291-}}
\item{\code{diag6description}}{a factor with levels \code{} \code{Disturbances of sodium balance of newborn}}
\item{\code{v23}}{a factor with levels \code{} \code{P742-}}
\item{\code{diag7description}}{a factor with levels \code{} \code{Disturbances of potassium balance of newborn}}
\item{\code{v25}}{a factor with levels \code{} \code{P743-}}
\item{\code{diag8description}}{a factor with levels \code{} \code{Vomiting in newborn}}
\item{\code{v27}}{a factor with levels \code{} \code{P920-}}
\item{\code{diag9description}}{a factor with levels \code{} \code{Other and unspecified convulsions}}
\item{\code{v29}}{a factor with levels \code{} \code{R568-}}
\item{\code{diag10description}}{a factor with levels \code{} \code{Bacterial sepsis of newborn, unspecified}}
\item{\code{v31}}{a factor with levels \code{} \code{P369-}}
\item{\code{diag11description}}{a logical vector}
\item{\code{v33}}{a logical vector}
\item{\code{diag12description}}{a logical vector}
\item{\code{v35}}{a logical vector}
\item{\code{diag13description}}{a logical vector}
\item{\code{v37}}{a logical vector}
\item{\code{diag14description}}{a logical vector}
\item{\code{v39}}{a logical vector}
\item{\code{diag15description}}{a logical vector}
\item{\code{v41}}{a logical vector}
\item{\code{diag16description}}{a logical vector}
\item{\code{v43}}{a logical vector}
\item{\code{diag17description}}{a logical vector}
\item{\code{v45}}{a logical vector}
\item{\code{diag18description}}{a logical vector}
\item{\code{v47}}{a logical vector}
\item{\code{diag19description}}{a logical vector}
\item{\code{v49}}{a logical vector}
\item{\code{diag20description}}{a logical vector}
\item{\code{v51}}{a logical vector}
\item{\code{oper1description}}{a factor with levels \code{-} \code{Other specified continuous Infusion of therapeutic substance} \code{Unspecified diagnostic spinal puncture}}
\item{\code{mainoperativeprocedure}}{a factor with levels \code{-} \code{A559} \code{X298}}
\item{\code{oper2description}}{a logical vector}
\item{\code{stsecondaryoperativeprocedure}}{a logical vector}
\item{\code{oper3description}}{a logical vector}
\item{\code{ndsecondaryoperativeprocedure}}{a logical vector}
\item{\code{oper4description}}{a logical vector}
\item{\code{rdsecondaryoperativeprocedure}}{a logical vector}
\item{\code{oper5description}}{a logical vector}
\item{\code{thsecondaryoperativeprocedure}}{a logical vector}
\item{\code{procode5description}}{a factor with levels \code{DONCASTER ROYAL INFIRMARY} \code{EAST SUSSEX HOSPITALS NHS TRUST} \code{HEATHERWOOD AND WEXHAM PARK HOSPITALS NHS FOUNDATION TRUST} \code{OXFORD RADCLIFFE HOSPITALS NHS TRUST} \code{PORTSMOUTH HOSPITALS NHS TRUST} \code{SOUTHAMPTON UNIVERSITY HOSPITALS NHS TRUST} \code{ST GEORGE'S HEALTHCARE NHS TRUST WORTHING AND SOUTHLANDS HOSPITALS NHS TRUST
digitprovidercodea factor with levels RD7 RHM00 RHU00 RJ700 RP5DR RPL00 RTH00 RXC00
administrativecategorya numeric vector
1 2 | data(suscdata_sample)
## maybe str(suscdata_sample) ; plot(suscdata_sample) ...
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.